﻿Type=Class
Version=3.71
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private ws As WebSocket 'ignore
	' will hold our page information
	Public page As ABMPage
	' page theme
	Private theme As ABMTheme
	' to access the constants
	Private ABM As ABMaterial 'ignore	
	' name of the page, must be the same as the class name (case sensitive!)
	Public Name As String = "CompActionButtonPage"
	' name of the app, same as in ABMApplication
	Public AppName As String = "demo"
	
	' your own variables
	Dim myToastId As Int
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	' build the local structure IMPORTANT!
	BuildPage
End Sub

Private Sub WebSocket_Connected (WebSocket1 As WebSocket)
	Log("Connected")
	ws = WebSocket1	
	If ABMShared.NeedsAuthorization Then
		If ws.Session.GetAttribute2("IsAuthorized", "") = "" Then
			ABMShared.NavigateToPage(ws, "../")
			Return
		End If
	End If
	' connect our page with the websocket	
	page.SetWebSocket(ws)
	' Prepare the page IMPORTANT!
	page.Prepare	
End Sub

Private Sub WebSocket_Disconnected
	Log("Disconnected")
End Sub

Sub Page_ParseEvent(Params As Map) 
	Dim eventName As String = Params.Get("eventname")
	Dim eventParams() As String = Regex.Split(",",Params.Get("eventparams"))
	If SubExists(Me, eventName) Then
		Params.Remove("eventname")
		Params.Remove("eventparams")
		Select Case Params.Size
			Case 0
				CallSub(Me, eventName)
			Case 1
				CallSub2(Me, eventName, Params.Get(eventParams(0)))					
			Case 2
				If Params.get(eventParams(0)) = "abmistable" Then
					Dim PassedTables As List = ABM.ProcessTablesFromTargetName(Params.get(eventParams(1)))
					CallSub2(Me, eventName, PassedTables)
				Else
					CallSub3(Me, eventName, Params.Get(eventParams(0)), Params.Get(eventParams(1)))
				End If
			Case Else
				' cannot be called diretly, to many param
				CallSub2(Me, eventName, Params)				
		End Select
	End If
End Sub

public Sub BuildTheme()
	' start with the base theme defined in ABMShared
	theme.Initialize("pagetheme")
	theme.AddABMTheme(ABMShared.MyTheme)
	
	' add additional themes specific for this page
	theme.AddButtonTheme("bigblue")
	theme.Button("bigblue").BackColor = ABM.COLOR_LIGHTBLUE
	
	theme.AddButtonTheme("sub1")
	theme.Button("sub1").BackColor = ABM.COLOR_RED
	
	theme.AddButtonTheme("sub2")
	theme.Button("sub2").BackColor = ABM.COLOR_GREEN
	
	theme.AddButtonTheme("sub3")
	theme.Button("sub3").BackColor = ABM.COLOR_YELLOW
	
	theme.AddCardTheme("whitetitle")
	theme.Card("whitetitle").TitleForeColor = ABM.COLOR_WHITE
End Sub

public Sub BuildPage()
	' initialize the theme
	BuildTheme
	
	' initialize this page using our theme
	page.InitializeWithTheme(Name, "/ws/" & AppName & "/" & Name, False, theme)
	page.ShowLoader=True
		
	ABMShared.BuildNavigationBar(page, "ABMActionButton", "../images/logo.png", "", "Controls", "ABMActionButton")
	
	' create the page grid
	page.AddRows(3,True, "").AddCells12(1,"")
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,8,6,"")
	page.AddRows(1,True, "").AddCells12(1,"")
	page.BuildGrid 'IMPORTANT once you loaded the complete grid AND before you start adding components
	
	' create the action button
	Dim acb1 As ABMActionButton
	acb1.Initialize(page, "acb1", "mdi-action-shop", "bigblue")
	acb1.MainButton.Large = True
	
	' the sub buttons
	Dim btn1 As ABMButton
	btn1.InitializeFloating(page, "btn1", "mdi-social-share", "sub1")
	acb1.AddMenuButton(btn1)
	Dim btn2 As ABMButton
	btn2.InitializeFloating(page, "btn2", "mdi-social-whatshot", "sub2")
	acb1.AddMenuButton(btn2)
	Dim btn3 As ABMButton
	btn3.InitializeFloating(page, "btn3", "mdi-social-notifications", "sub3")
	acb1.AddMenuButton(btn3)
	
	' add to page
	page.AddActionButton(acb1)
	
	' add paragraph	
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par1","Action buttons are buttons that can open a sub menu of buttons. They are generaly used on page level, but they can also be set at cell level.") )
	' add a header label
	page.Cell(1,1).AddComponent(ABMShared.BuildHeader(page,"hdr1", "Page Level"))
	' add paragraph	
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par2","The big blue button on the bottom right is an example of a page ActionButton.") )
	
	' code block
	Dim code As StringBuilder
	code.Initialize
	code.Append("// create the action button").Append(CRLF)
	code.Append("Dim acb1 As ABMActionButton").Append(CRLF)
	code.Append("acb1.Initialize(page, ""acb1"", ""mdi-action-shop"", ""bigblue"")").Append(CRLF)
	code.Append("acb1.MainButton.Large = True").Append(CRLF)
	code.Append("").Append(CRLF)
	code.Append("// the sub buttons").Append(CRLF)
	code.Append("Dim btn1 As ABMButton").Append(CRLF)
	code.Append("btn1.InitializeFloating(page, ""btn1"", ""mdi-social-share"", ""sub1"")").Append(CRLF)
	code.Append("acb1.AddMenuButton(btn1)").Append(CRLF)
	code.Append("Dim btn2 As ABMButton").Append(CRLF)
	code.Append("btn2.InitializeFloating(page, ""btn2"", ""mdi-social-whatshot"", ""sub2"")").Append(CRLF)
	code.Append("acb1.AddMenuButton(btn2)").Append(CRLF)
	code.Append("Dim btn3 As ABMButton").Append(CRLF)
	code.Append("btn3.InitializeFloating(page, ""btn3"", ""mdi-social-notifications"", ""sub3"")").Append(CRLF)
	code.Append("acb1.AddMenuButton(btn3)").Append(CRLF)
	code.Append("").Append(CRLF)
	code.Append("// add To page").Append(CRLF)
	code.Append("page.AddActionButton(acb1)").Append(CRLF)
	
	page.Cell(2,1).AddComponent(ABMShared.BuildCodeBlock(page, "code", code))
	
	' add a header label
	page.Cell(3,1).AddComponent(ABMShared.BuildHeader(page,"hdr1", "Cell Level"))
	' add paragraph	
	page.Cell(3,1).AddComponent(ABMShared.BuildParagraph(page,"par2","You can also add an action button to a cell.") )
	
	' image card
	Dim card2 As ABMCard
	card2.InitializeAsCard(page, "card2", "Card Title", "I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively.", ABM.CARD_NOTSPECIFIED,"whitetitle")
	card2.Image = "../images/sample-1.jpg"
	card2.AddAction("BUTTON 1")
	page.Cell(4,1).AddComponent(card2)
	
	' create the action button
	Dim acb2 As ABMActionButton
	acb2.Initialize(page, "acb2", "mdi-action-shop", "sub1")
			
	' the sub buttons	
	Dim btn4 As ABMButton
	btn4.InitializeFloating(page, "btn4", "mdi-social-whatshot", "sub2")
	acb2.AddMenuButton(btn4)
	Dim btn5 As ABMButton
	btn5.InitializeFloating(page, "btn5", "mdi-social-notifications", "sub3")
	acb2.AddMenuButton(btn5)	
	
	' add to cell
	page.Cell(4,1).AddComponent(acb2)
	
	' add paragraph	
	page.Cell(5,1).AddComponent(ABMShared.BuildParagraph(page,"par3","The only difference with the page ActionButton is we've added it to the cell as a normal control.") )
	
	' code block
	Dim code2 As StringBuilder
	code2.Initialize
	code2.Append("acb2.Initialize(page, ""acb2"", ""mdi-action-shop"", ""sub1"")").Append(CRLF)
	code2.Append("...").Append(CRLF)
	code2.Append("page.AddComponent(4,1, acb2)").Append(CRLF)
	
	page.Cell(5,1).AddComponent(ABMShared.BuildCodeBlock(page, "code2", code2))
	
	ABMShared.BuildFooter(page)
End Sub

' clicked on the navigation bar
Sub Page_NavigationbarClicked(Action As String, Value As String)
	page.SaveNavigationBarPosition	
	If Action = "ABMActionButton" Then Return
	If Action = "Contact" Then		
		myToastId = myToastId + 1
		page.ShowToast("toast" & myToastId, "toastred", "Hello to you too!", 5000)
		Return
	End If
	ABMShared.NavigateToPage(ws, Value)
End Sub

Sub Page_Ready()
	Log("ready!")
	page.RestoreNavigationBarPosition
End Sub

Sub acb1_Clicked(Target As String, SubTarget As String)
	If SubTarget="" Then Return
	Dim myTexts, myReturns As List
	myTexts.Initialize
	myReturns.Initialize
	myToastId = myToastId + 1
	page.ShowToast("toast" & myToastId, "toastred", "Clicked on " & SubTarget, 5000)
	Return
End Sub

Sub acb2_Clicked(Target As String, SubTarget As String)
	If SubTarget="" Then Return
	Dim myTexts, myReturns As List
	myTexts.Initialize
	myReturns.Initialize
	myToastId = myToastId + 1
	page.ShowToast("toast" & myToastId, "toastred", "Clicked on " & SubTarget, 5000)
	Return
End Sub