﻿Type=Class
Version=3.71
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private ws As WebSocket 'ignore
	' will hold our page information
	Public page As ABMPage
	' page theme
	Private theme As ABMTheme
	' to access the constants
	Private ABM As ABMaterial 'ignore	
	' name of the page, must be the same as the class name (case sensitive!)
	Public Name As String = "CompUploadPage"
	' name of the app, same as in ABMApplication
	Public AppName As String = "demo"
	' the download folder
	Public DownloadFolder As String = "\www\" & AppName & "\uploads\"
	Public DownloadMaxSize As String = 2*1024*1024*1024
	
	' your own variables
	Dim myToastId As Int	
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	' build the local structure IMPORTANT!
	BuildPage
End Sub

Private Sub WebSocket_Connected (WebSocket1 As WebSocket)
	Log("Connected")
	ws = WebSocket1	
	' connect our page with the websocket	
	page.SetWebSocket(ws)
	If ABMShared.NeedsAuthorization Then
		If ws.Session.GetAttribute2("IsAuthorized", "") = "" Then
			ABMShared.NavigateToPage(ws, "../")
			Return
		End If
	End If
	' Prepare the page IMPORTANT!
	page.Prepare	
	' this page uses uploads, so needs some settings	
	ws.Session.SetAttribute("abmcallback", Me)	
	ws.Session.SetAttribute("abmdownloadfolder", DownloadFolder)
	ws.Session.SetAttribute("abmmaxsize", DownloadMaxSize)
End Sub

Private Sub WebSocket_Disconnected
	Log("Disconnected")
	' and remove them again
	Try
		ws.Session.RemoveAttribute("abmcallback")	
		ws.Session.RemoveAttribute("abmdownloadfolder")
		ws.Session.RemoveAttribute("abmmaxsize")
	Catch
		Log(LastException.Message)
	End Try
End Sub

Sub Page_ParseEvent(Params As Map) 
	Dim eventName As String = Params.Get("eventname")
	Dim eventParams() As String = Regex.Split(",",Params.Get("eventparams"))
	If SubExists(Me, eventName) Then
		Params.Remove("eventname")
		Params.Remove("eventparams")
		Select Case Params.Size
			Case 0
				CallSub(Me, eventName)
			Case 1
				CallSub2(Me, eventName, Params.Get(eventParams(0)))					
			Case 2
				If Params.get(eventParams(0)) = "abmistable" Then
					Dim PassedTables As List = ABM.ProcessTablesFromTargetName(Params.get(eventParams(1)))
					CallSub2(Me, eventName, PassedTables)
				Else
					CallSub3(Me, eventName, Params.Get(eventParams(0)), Params.Get(eventParams(1)))
				End If
			Case Else
				' cannot be called diretly, to many param
				CallSub2(Me, eventName, Params)				
		End Select
	End If
End Sub

public Sub BuildTheme()
	' start with the base theme defined in ABMShared
	theme.Initialize("pagetheme")
	theme.AddABMTheme(ABMShared.MyTheme)
	
	' add additional themes specific for this page
	' another toast theme
	theme.AddToastTheme("toastgreen")
	theme.Toast("toastgreen").Rounded = True
	theme.Toast("toastgreen").ActionForeColor = ABM.COLOR_BLACK
	theme.Toast("toastgreen").BackColor = ABM.COLOR_GREEN
End Sub

public Sub BuildPage()
	' initialize the theme
	BuildTheme
	
	' initialize this page using our theme
	page.InitializeWithTheme(Name, "/ws/" & AppName & "/" & Name, False, theme)
	page.ShowLoader=True
		
	ABMShared.BuildNavigationBar(page, "ABMUpload", "../images/logo.png", "", "Controls", "ABMUpload")
		
	' create the page grid
	page.AddRows(7,True, "").AddCells12(1,"")
	page.BuildGrid 'IMPORTANT once you loaded the complete grid AND before you start adding components
	
	' add paragraph
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page, "par1","ABMUpload is a control to upload files to the server.  You can drag/drop files into the dropzone or use the button to select files. The files will start uploading immediately one after each other.  The user can cancel the upload clicking the 'x'."))
		
	' create the upload
	Dim upload1 As ABMUpload
	upload1.Initialize(page, "upload1", "Drop Here", "Browse", "")
	page.Cell(2,1).AddComponent(upload1)
		
	' add codeblock	
	Dim code As String = $"// create the upload
Dim upload1 As ABMUpload
upload1.Initialize(page, "upload1", "Drop Here", "Browse", True, "")
page.Cell(2,1).AddComponent(upload1)"$
	
	page.Cell(3,1).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code1", code))
	
	' add paragraph
	page.Cell(4,1).AddComponent(ABMShared.BuildParagraph(page, "par1","When the download is finished, you'll receive an FileUploaded() event on the page."))
	
	' add codeblock	
	code = $"Sub Page_FileUploaded(FileName As String, success As Boolean)
   myToastId = myToastId + 1	
   If success Then
      page.ShowToast("toast" & myToastId, "toastgreen", "File " & FileName & " uploaded!", 5000)
   Else
      page.ShowToast("toast" & myToastId, "toastred", "File " & FileName & " uploaded!", 5000)
   End If
   page.ws.Flush // IMPORTANT
End Sub"$

	page.Cell(5,1).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code2", code))
	
	' add paragraph
	page.Cell(6,1).AddComponent(ABMShared.BuildParagraph(page, "par2","Additionally, you have to add the following lines of code to WebSocket_Connected() and WebSocket_Disconnected()!"))
	
	' add codeblock	
	code = $"// In WebSocket_Connected()
ws.Session.SetAttribute("abmcallback", Me)	
ws.Session.SetAttribute("abmdownloadfolder", DownloadFolder)
ws.Session.SetAttribute("abmmaxsize", DownloadMaxSize)"$

	page.Cell(7,1).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code3", code))
	' add codeblock	
	code = $"// In WebSocket_Disconnected()
Try
	ws.Session.RemoveAttribute("abmcallback")	
	ws.Session.RemoveAttribute("abmdownloadfolder")
	ws.Session.RemoveAttribute("abmmaxsize")
Catch
	Log(LastException.Message)
End Try"$

	page.Cell(7,1).AddComponent(ABMShared.BuildCodeBlockFromSmartString(page, "code4", code))
	
	ABMShared.BuildFooter(page)
End Sub

' clicked on the navigation bar
Sub Page_NavigationbarClicked(Action As String, Value As String)
	page.SaveNavigationBarPosition	
	If Action = "ABMUpload" Then Return
	If Action = "Contact" Then	
		myToastId = myToastId + 1	
		page.ShowToast("toast" & myToastId, "toastred", "Hello to you too!", 5000)
		Return
	End If
	ABMShared.NavigateToPage(ws, Value)
End Sub

Sub Page_Ready()
	Log("ready!")
	page.RestoreNavigationBarPosition
End Sub

Sub Page_FileUploaded(FileName As String, success As Boolean)
	myToastId = myToastId + 1	
	If success Then
		page.ShowToast("toast" & myToastId, "toastgreen", "File " & FileName & " uploaded!", 5000)
	Else
		page.ShowToast("toast" & myToastId, "toastred", "File " & FileName & " uploaded!", 5000)
	End If
	page.ws.Flush ' IMPORTANT
End Sub